pub fn expected_nbytes(dtype: TensorDtype, shape: &[usize]) -> Option<usize>Expand description
Expected byte length of a tensor given dtype and element count.
pub fn expected_nbytes(dtype: TensorDtype, shape: &[usize]) -> Option<usize>Expected byte length of a tensor given dtype and element count.